<?php

/**
 * MyBB 1.6
 * Copyright 2012 MyBB-Es Group, All Rights Reserved
 *
 * Website: http://ww.mybb-es.com
 *
 * $Id: class_admin.php 5297 2012-04-07 13:43 EdsonOrdaz $
 */
 
class nickstyles_admin extends DataHandler 
{
	/**
	 * Muestra las pestaas en el ACP
	 *
	 * @param Ingresa la pestaa activa 'default' home
	 * @array extra permite agregar y mostrar la pestaa editar por medio de este array
	 */
	public function tabs($location='home', $extra=array())
	{
		global $page, $lang;
		$tabs["home"] = array(
			'title' => $lang->nickstyles,
			'link' => "index.php?module=user-nickstyles",
			'description' => $lang->hometabdes
		);
		$tabs["new"] = array(
			'title' => $lang->newnickstyles,
			'link' => "index.php?module=user-nickstyles&action=new",
			'description' => $lang->newnickstylesdes
		);
		if($extra['edit'] == 1)
		{
			$tabs["edit"] = array(
				'title' => $lang->edit,
				'link' => "index.php?module=user-nickstyles&amp;action=edit&nid=".$extra['nid'],
				'description' => $lang->edittabdes
			);
		}
		$tabs["editmassive"] = array(
			'title' => $lang->editmassive,
			'link' => "index.php?module=user-nickstyles&action=editmassive",
			'description' => $lang->editmassivedestab
		);
		$page->output_nav_tabs($tabs, $location);
	}
	
	/**
	 * Validate Informacion
	 *
	 * Valida la informacion procesaa al crear un estilo
	 */
	public function validate_information()
	{
		global $lang;
		$style = &$this->data;
		if(empty($style['name']))
		{
			$this->set_error($lang->notname);
		}
		if(empty($style['style']))
		{
			$this->set_error($lang->notstyle);
		}
		if(my_strpos($style['style'], "{username}") === false)
		{
			$this->set_error($lang->notusername);
		}
		if($style['online'] < 0)
		{
			$this->set_error($lang->invalidtime);
		}
		$this->set_validated(true);
		if(count($this->get_errors()) > 0)
		{
			return false;
		}
		else
		{
			return true;
		}
	}
	
	
	/**
	 * Inserta el estilo
	 *
	 * Si no hay errores en la validacion inserta
	 * el estilo en la DB.
	 *
	 * Es obligatorio que pase por un proceso de validacion.
	 */
	public function insert_style()
	{
		global $lang, $db;
		if(!$this->get_validated())
		{
			die($lang->not_validate);
		}
		if(count($this->get_errors()) > 0)
		{
			die($lang->infonotvalid);
		}
		$style = &$this->data;
		$update = array( 
			"name" => $style['name'],
			"style" => $style['style'],
			"posts" => $style['posts'],
			"reputation" => $style['reputation'],
			"days" => intval($style['day']),
			"months" => intval($style['month']),
			"online" => intval($style['online']),
			"groups" => $style['groups'],
			"disporder" => $style['disporder']
		); 
		$nid = $db->insert_id();
		$db->insert_query("nickstyles_nicks", $update);
	}
	
	
	/**
	 * Update Style
	 *
	 * Actualzia un estilo creado (Es necesario validar la informacion)
	 */
	public function update_style()
	{
		global $lang, $db;
		if(!$this->get_validated())
		{
			die($lang->not_validate);
		}
		if(count($this->get_errors()) > 0)
		{
			die($lang->infonotvalid);
		}
		$style = &$this->data;
		$update = array( 
			"name" => $style['name'],
			"style" => $style['style'],
			"posts" => $style['posts'],
			"reputation" => $style['reputation'],
			"days" => intval($style['day']),
			"months" => intval($style['month']),
			"online" => intval($style['online']),
			"groups" => $style['groups'],
			"disporder" => $style['disporder']
		); 
		$db->update_query("nickstyles_nicks", $update, "nid=".$style['nid']);
	}
	
	
	/**
	 * Delete Style
	 *
	 * Elimina el esilo seleccionado.
	 */
	public function deletestyle()
	{
		global $db, $lang, $mybb;
		$query = $db->simple_select("nickstyles_nicks", "*", "nid=".$mybb->input['nid']);
		$style = $db->fetch_array($query);
		$lang->successdeletestyle = $lang->sprintf($lang->deletesuccess, $style['name']);
		$db->query("DELETE FROM ".TABLE_PREFIX."nickstyles_nicks WHERE nid='".intval($mybb->input['nid'])."'");
		$db->free_result($query);
		messageadmin($lang->successdeletestyle);
	}
	
	
	/**
	 * Validate edit massive
	 *
	 * Valida la informacion al editar masivamente
	 * los datos de todos los estilo
	 */
	public function validate_editmassive()
	{
		global $lang;
		$style = &$this->data;
		if($style['online'] < 0)
		{
			$this->set_error($lang->invalidtime);
		}
		$this->set_validated(true);
		if(count($this->get_errors()) > 0)
		{
			return false;
		}
		else
		{
			return true;
		}
	}
	
	
	/**
	 * Muestra las pestaas en el ACP
	 *
	 * @param Ingresa la pestaa activa 'default' home
	 * @array extra permite agregar y mostrar la pestaa editar por medio de este array
	 */
	public function update_edit_massive()
	{
		global $lang, $db;
		if(!$this->get_validated())
		{
			die($lang->not_validate);
		}
		if(count($this->get_errors()) > 0)
		{
			die($lang->infonotvalid);
		}
		$style = &$this->data;
		$update = array( 
			"posts" => $style['posts'],
			"reputation" => $style['reputation'],
			"days" => intval($style['day']),
			"months" => intval($style['month']),
			"online" => intval($style['online']),
			"groups" => $style['groups']
		); 
		$db->update_query("nickstyles_nicks", $update);
	}
}
?>